"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var configcat_common_1 = require("configcat-common");
var axios_1 = require("axios");
var HttpConfigFetcher = /** @class */ (function () {
    function HttpConfigFetcher() {
    }
    HttpConfigFetcher.prototype.fetchLogic = function (options, lastEtag, callback) {
        var axiosConfig = {
            method: 'get',
            timeout: options.requestTimeoutMs,
            url: options.getUrl(),
            headers: {
                'X-ConfigCat-UserAgent': "ConfigCat-JS-SSR/" + options.clientVersion,
                'If-None-Match': (lastEtag) ? lastEtag : null
            }
        };
        axios_1.default(axiosConfig)
            .then(function (response) {
            var eTag = response.headers.etag;
            if (response.status === 200) {
                callback(configcat_common_1.FetchResult.success(JSON.stringify(response.data), eTag));
            }
            else {
                options.logger.error("Failed to download feature flags & settings from ConfigCat. " + response.status + " - " + response.statusText);
                options.logger.info("Double-check your SDK Key on https://app.configcat.com/sdkkey");
                callback(configcat_common_1.FetchResult.error());
            }
        })
            .catch(function (error) {
            if (error.response) {
                if (error.response.status === 304) {
                    callback(configcat_common_1.FetchResult.notModified());
                }
                else {
                    options.logger.error("Failed to download feature flags & settings from ConfigCat. " + error.response.status + " - " + error.response.statusText);
                    options.logger.info("Double-check your SDK Key on https://app.configcat.com/sdkkey");
                    callback(configcat_common_1.FetchResult.error());
                }
            }
            else if (error.request) {
                options.logger.error('The request to Configcat was made but no response was received');
                callback(configcat_common_1.FetchResult.error());
            }
            else {
                options.logger.error("Something happened in setting up the request to ConfigCat: " + error.message);
                callback(configcat_common_1.FetchResult.error());
            }
        });
    };
    return HttpConfigFetcher;
}());
exports.HttpConfigFetcher = HttpConfigFetcher;
